---
title: Presenter Output
---

### Presenter Output

This section will show you how to use the decorated value provided by the `\Anomaly\GeocoderFieldType\GeocoderFieldTypePresenter` class.


#### GeocoderFieldTypePresenter::image()

The `image` method returns a generated image of the map area.

###### Returns: `string`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$options

</td>

<td>

false

</td>

<td>

array

</td>

<td>

none

</td>

<td>

The image options.

</td>

</tr>

<tr>

<td>

$formatted

</td>

<td>

true

</td>

<td>

boolean

</td>

<td>

false

</td>

<td>

Use the formatted address location instead of the potentially adjusted marker location.

</td>

</tr>

</tbody>

</table>

###### Example

    $decorated->example->image();

###### Twig

    {{ decorated.example.image()|raw }}


##### Available Option

Below are a list of available `options` for the image method's `options` argument.

###### Properties

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

scale

</td>

<td>

false

</td>

<td>

integer

</td>

<td>

1

</td>

<td>

The scale of the map.

</td>

</tr>

<tr>

<td>

zoom

</td>

<td>

false

</td>

<td>

integer

</td>

<td>

The configured zoom.

</td>

<td>

The zoom of the map.

</td>

</tr>

<tr>

<td>

format

</td>

<td>

false

</td>

<td>

string

</td>

<td>

png

</td>

<td>

The output format of the image. Valid options are `jpg` and `png`.

</td>

</tr>

<tr>

<td>

maptype

</td>

<td>

false

</td>

<td>

string

</td>

<td>

roadmap

</td>

<td>

The Google maptype. Valid options are `roadmap`, `satellite`, `hybrid`, and `terrain`.

</td>

</tr>

<tr>

<td>

width

</td>

<td>

false

</td>

<td>

integer

</td>

<td>

150

</td>

<td>

The width of the resulting image.

</td>

</tr>

<tr>

<td>

height

</td>

<td>

false

</td>

<td>

integer

</td>

<td>

100

</td>

<td>

The height of the resulting image.

</td>

</tr>

</tbody>

</table>


#### GeocoderFieldTypePresenter::embed()

The `embed` method returns an embedded Google map.

<div class="alert alert-warning">**Heads Up:** The embedded map is 0px high by default. Be sure to use CSS to style it or set the height option as described below.</div>

###### Returns: `string`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$options

</td>

<td>

false

</td>

<td>

array

</td>

<td>

none

</td>

<td>

The image options.

</td>

</tr>

<tr>

<td>

$formatted

</td>

<td>

true

</td>

<td>

boolean

</td>

<td>

false

</td>

<td>

Use the formatted address location instead of the potentially adjusted marker location.

</td>

</tr>

</tbody>

</table>

###### Example

    $decorated->example->embed()->height(500);

###### Twig

    {{ decorated.example.embed().height(500)|raw }}


##### Available Options

Below are a list of available `options` for the embed method's `options` argument.

###### Options

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

scale

</td>

<td>

false

</td>

<td>

integer

</td>

<td>

1

</td>

<td>

The scale of the map.

</td>

</tr>

<tr>

<td>

scrollwheel

</td>

<td>

false

</td>

<td>

boolean

</td>

<td>

true

</td>

<td>

Set to `false` to disable scrollwheel interaction.

</td>

</tr>

<tr>

<td>

zoom

</td>

<td>

false

</td>

<td>

integer

</td>

<td>

15

</td>

<td>

The output map zoom.

</td>

</tr>

<tr>

<td>

height

</td>

<td>

false

</td>

<td>

integer

</td>

<td>

none

</td>

<td>

The style height in pixels if any of the map div.

</td>

</tr>

</tbody>

</table>


#### GeocoderFieldTypePresenter::url()

The `url` method returns the Google Maps URL for the address.

###### Returns: `string`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$formatted

</td>

<td>

false

</td>

<td>

boolean

</td>

<td>

false

</td>

<td>

Use the formatted address location instead of the potentially adjusted marker location.

</td>

</tr>

</tbody>

</table>

###### Example

    $decorated->example->url();

###### Twig

    {{ decorated.example.url() }}


#### GeocoderFieldTypePresenter::link()

The `link` method returns an HTML link to the Google Maps URL.

###### Returns: `string`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$title

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The link title.

</td>

</tr>

<tr>

<td>

$attributes

</td>

<td>

false

</td>

<td>

array

</td>

<td>

none

</td>

<td>

The array of HTML attributes of the link.

</td>

</tr>

<tr>

<td>

$secure

</td>

<td>

false

</td>

<td>

boolean

</td>

<td>

True if request is secure.

</td>

<td>

Force a secure URL.

</td>

</tr>

<tr>

<td>

$formatted

</td>

<td>

false

</td>

<td>

boolean

</td>

<td>

false

</td>

<td>

Use the formatted address location instead of the potentially adjusted marker location.

</td>

</tr>

</tbody>

</table>


#### GeocoderFieldTypePresenter::position()

The `position` method returns an array containing the `longitude` and `latitude` values.

###### Returns: `array`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$formatted

</td>

<td>

false

</td>

<td>

boolean

</td>

<td>

false

</td>

<td>

Use the formatted address location instead of the potentially adjusted marker location.

</td>

</tr>

</tbody>

</table>

###### Example

    $decorated->example->position()['longitude'];

###### Twig

    {{ decorated.example.position().longitude }}


#### GeocoderFieldTypePresenter::latitude()

The `latitude` method is a shortcut to return the value's latitude position.

###### Returns: `float`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$formatted

</td>

<td>

false

</td>

<td>

boolean

</td>

<td>

false

</td>

<td>

Use the formatted address location instead of the potentially adjusted marker location.

</td>

</tr>

</tbody>

</table>

###### Example

    $deocrated->example->latitude();

###### Twig

    {{ decorated.example.latitude() }}


#### GeocoderFieldTypePresenter::longitude()

The `longitude` method is a shortcut to return the value's longitude position.

###### Returns: `float`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$formatted

</td>

<td>

false

</td>

<td>

boolean

</td>

<td>

false

</td>

<td>

Use the formatted address location instead of the potentially adjusted marker location.

</td>

</tr>

</tbody>

</table>

###### Example

    $decorated->example->longitude();

###### Twig

    {{ decorated.example.longitude() }}


#### GeocoderFieldTypePresenter::point()

The `point` method returns a `Point` instance for use within spatial utilities.

###### Returns: `\Anomaly\GeocoderFieldType\Spatial\Point`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$formatted

</td>

<td>

false

</td>

<td>

bool

</td>

<td>

none

</td>

<td>

Whether to use the formatted latitude and longitude instead of the adjustable marker.

</td>

</tr>

</tbody>

</table>

###### Example

    $decorated->point();

###### Twig

    {{ decorated.point() }}


#### GeocoderFieldTypePresenter::geocode()

The `geocode` method returns a _geocoder_ point (as opposed to the above _spatial_ point).

###### Returns: `\Anomaly\GeocoderFieldType\GeocoderFieldTypePoint`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$formatted

</td>

<td>

false

</td>

<td>

bool

</td>

<td>

none

</td>

<td>

Whether to use the formatted address instead of the input address.

</td>

</tr>

</tbody>

</table>

###### Example

    echo $decorated->geocode->city() . ', ' . $decorated->geocode->state();

###### Twig

    {{ entry.location.geocode.city() }}, {{ entry.location.geocode.state() }}

